@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2014 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,60 +50,82 @@
 package com.openexchange.user.copy;
 
 import com.openexchange.exception.Category;
+import com.openexchange.exception.DisplayableOXExceptionCode;
 import com.openexchange.exception.OXException;
-import com.openexchange.exception.OXExceptionCode;
 import com.openexchange.exception.OXExceptionFactory;
+import com.openexchange.exception.OXExceptionStrings;
 
 /**
  * Lists all possible exceptions that can occur when a user is moved.
  *
  * @author <a href="mailto:marcus.klein@open-xchange.com">Marcus Klein</a>
  */
-public enum UserCopyExceptionCodes implements OXExceptionCode {
+public enum UserCopyExceptionCodes implements DisplayableOXExceptionCode {
 
     /** Unable to determine next update task to execute. Enqueued: %1$s. To sort: %2$s. */
-    UNRESOLVABLE_DEPENDENCIES(UserCopyExceptionMessages.UNRESOLVABLE_DEPENDENCIES_MSG, Category.CATEGORY_ERROR, 1),
+    UNRESOLVABLE_DEPENDENCIES("Unable to determine next copy task to execute. Enqueued: %1$s. To sort: %2$s.", Category.CATEGORY_ERROR, 1,
+        null),
+
     /** SQL Problem. */
-    SQL_PROBLEM(UserCopyExceptionMessages.SQL_PROBLEM_MSG, Category.CATEGORY_ERROR, 2),
+    SQL_PROBLEM("SQL problem.", Category.CATEGORY_ERROR, 2, OXExceptionStrings.SQL_ERROR_MSG),
+
     /** Severe problem occurred. */
-    UNKNOWN_PROBLEM(UserCopyExceptionMessages.UNKNOWN_PROBLEM_MSG, Category.CATEGORY_ERROR, 3),
+    UNKNOWN_PROBLEM("Unexpected problem occurred.", Category.CATEGORY_ERROR, 3, null),
+
     /** Problem with UserService. */
-    USER_SERVICE_PROBLEM(UserCopyExceptionMessages.USER_SERVICE_PROBLEM_MSG, Category.CATEGORY_ERROR, 4),
+    USER_SERVICE_PROBLEM("Problem with UserService.", Category.CATEGORY_ERROR, 4, null),
+
     /** A private folder (%1$s) without existing parent (%2$s) was found. */
-    MISSING_PARENT_FOLDER(UserCopyExceptionMessages.MISSING_PARENT_FOLDER_MSG, Category.CATEGORY_ERROR, 5),
+    MISSING_PARENT_FOLDER("A private folder (%1$s) without existing parent (%2$s) was found.", Category.CATEGORY_ERROR, 5,null),
+
     /** Database pooling error. */
-    DB_POOLING_PROBLEM(UserCopyExceptionMessages.DB_POOLING_PROBLEM_MSG, Category.CATEGORY_ERROR, 6),
+    DB_POOLING_PROBLEM("Database pooling error.", Category.CATEGORY_ERROR, 6, OXExceptionStrings.SQL_ERROR_MSG),
+
     /** Problem with FileStorage. */
-    FILE_STORAGE_PROBLEM(UserCopyExceptionMessages.FILE_STORAGE_PROBLEM_MSG, Category.CATEGORY_ERROR, 7),
+    FILE_STORAGE_PROBLEM("Problem with FileStorage.", Category.CATEGORY_ERROR, 7, null),
+
     /** Could not generate a new sequence id for type %1$s. */
-    ID_PROBLEM(UserCopyExceptionMessages.ID_PROBLEM_MSG, Category.CATEGORY_ERROR, 8),
+    ID_PROBLEM("Could not generate a new sequence id for type %1$s.", Category.CATEGORY_ERROR, 8, null),
+
     /** Did not find contact for user %1$s in context %2$s. */
-    USER_CONTACT_MISSING(UserCopyExceptionMessages.USER_CONTACT_MISSING_MSG, Category.CATEGORY_ERROR, 9),
+    USER_CONTACT_MISSING("Did not find contact for user %1$s in context %2$s.", Category.CATEGORY_ERROR, 9, null),
+
     /** Could not save user's mail settings. */
-    SAVE_MAIL_SETTINGS_PROBLEM(UserCopyExceptionMessages.SAVE_MAIL_SETTINGS_PROBLEM_MSG, Category.CATEGORY_ERROR, 10),
+    SAVE_MAIL_SETTINGS_PROBLEM("Could not save user's mail settings.", Category.CATEGORY_ERROR, 10, null),
+
      /** A user named %1$s already exists in destination context %2$s. */
-    USER_ALREADY_EXISTS(UserCopyExceptionMessages.USER_ALREADY_EXISTS_MSG, Category.CATEGORY_USER_INPUT, 11),
+    USER_ALREADY_EXISTS("A user named %1$s already exists in destination context %2$s.", Category.CATEGORY_USER_INPUT, 11,
+        UserCopyExceptionMessages.USER_ALREADY_EXISTS_MSG),
     ;
 
     private final String message;
     private final Category category;
     private final int number;
+    private String displayMessage;
 
 
-    private UserCopyExceptionCodes(final String message, final Category category, final int number) {
+    private UserCopyExceptionCodes(final String message, final Category category, final int number, String displayMessage) {
         this.message = message;
         this.category = category;
         this.number = number;
+        this.displayMessage = displayMessage != null ? displayMessage : OXExceptionStrings.MESSAGE;
     }
 
+    @Override
     public String getMessage() {
         return message;
     }
 
+    @Override
     public Category getCategory() {
         return category;
     }
 
+    @Override
+    public String getDisplayMessage() {
+        return displayMessage;
+    }
+
     public OXException create(final Object... args) {
         return OXExceptionFactory.getInstance().create(this, args);
     }
@@ -112,14 +134,17 @@ public enum UserCopyExceptionCodes implements OXExceptionCode {
         return OXExceptionFactory.getInstance().create(this, cause, args);
     }
 
+    @Override
     public boolean equals(final OXException e) {
         return OXExceptionFactory.getInstance().equals(this, e);
     }
 
+    @Override
     public int getNumber() {
         return number;
     }
 
+    @Override
     public String getPrefix() {
         return "UCP";
     }
